% This code runs the Bayesian estimation of the "encompassing model" in Chang and Fernandez (2010)
% On the Sources of Aggregate Fluctuations in Emerging Economies. NBER WP
% 15938. April, 2010.

clear;
clc

% Load & Transform the data 
%--------------------------------------
load AGDataMEX %Aguiar and Gopinath Mexican data 

Y   = data(1:end,6) ;
C   = data(1:end,1) ;
Iv  = data(1:end,2) ;
NX  = data(1:end,5) ;
TBY = NX./Y ;

y   = log(Y(2:end,1)) - log(Y(1:end-1,1));
c   = log(C(2:end,1)) - log(C(1:end-1,1));
iv  = log(Iv(2:end,1)) - log(Iv(1:end-1,1));
tby = TBY(2:end,1) - TBY(1:end-1,1);

DATA = [y c iv tby]; %Data in growth rates for {Y,C,I} and differences {TB/Y}

% Running RWMH algorithm
%-----------------------

load V_vec  % Inverse of the Hessian at the mode found my maximizong the posterior. 
C = 0.4;    % Scaling parameter adjusted to obtain proper acceptance ratio
newV = C*V; % Constructing the covariance matrix V as suggested.

nsim = 150; % Number of iterations (150000 used in the paper)

[out,parnew,par,VarCov] = encompassing_estimation(nsim,newV,DATA); %First Iteration

% Plotting the parameter draws
%-----------------------------
 
t=1:1:nsim;
t=t';

figure(1)
subplot(2,7,1)
plot(t,out.pars(:,1))
title('\rho_a, prior mean 0.950 C1')

subplot(2,7,2)
plot(t,out.pars(:,2))
title('\rho_g, prior mean 0.72')

subplot(2,7,3)
plot(t,out.pars(:,3))
title('\rho_r, prior mean 0.83')

subplot(2,7,4)
plot(t,out.pars(:,4))
title('\theta, prior mean 0.5')

subplot(2,7,5)
plot(t,out.pars(:,5))
title('\sigma_a, prior mean 0.0075')

subplot(2,7,6)
plot(t,out.pars(:,6))
title('\sigma_g, prior mean 0.0075')

subplot(2,7,7)
plot(t,out.pars(:,7))
title('\sigma_r, prior mean 0.007')

subplot(2,7,8)
plot(t,out.pars(:,8))
title('\eta, prior mean 1.0')

subplot(2,7,9)
plot(t,out.pars(:,9))
title('\phi, prior mean 6.0')

subplot(2,7,10)
plot(t,out.pars(:,10))
title('\sigma_Y, prior mean 0.02')

subplot(2,7,11)
plot(t,out.pars(:,11))
title('\sigma_C, prior mean 0.02')

subplot(2,7,12)
plot(t,out.pars(:,12))
title('\sigma_I, prior mean 0.02')

subplot(2,7,13)
plot(t,out.pars(:,11))
title('\sigma_NX, prior mean 0.02')